.. StoryPy documentation master file.

.. meta::
   :description: StoryPy is a Python module for metaprogramming.
   :keywords: StoryPy, Python, metaprogramming, programming

StoryPy documentation
=====================

StoryPy is a Python module for metaprogramming.

This documentation provides the following:

* guides for using StoryPy in your project
* source code documentation (autogenerated)

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   guides
   modules
